"""
texere

Copyright (c) 2013-2014, Friedrich Paetzke (f.paetzke@gmail.com)
All rights reserved.

"""
from .texere import Texere

__version__ = '0.1.0'
__author__ = 'Friedrich Paetzke'
__license__ = 'BSD'
__copyright__ = 'Copyright 2013-2014 Friedrich Paetzke'

try:
    from contextlib import ContextDecorator
except ImportError:
    from functools import wraps

    class ContextDecorator(object):

        def __call__(self, f):
            @wraps(f)
            def decorated(*args, **kwargs):
                with self:
                    return f(*args, **kwargs)
            return decorated


def activate(language):
    Texere().language = language


def get_language():
    return Texere().language


def get_lazy_text(key, values=None):
    return Texere().get_lazy_text(key, values)


def get_text(key, values=None):
    return Texere().get_text(key, values)


def init_texere(dirname, language):
    Texere(dirname, language)


class switch_language(ContextDecorator):

    def __init__(self, language):
        self._language = language

    def __enter__(self):
        self._texere_obj = Texere()
        self._old_language = self._texere_obj.language
        self._texere_obj.language = self._language
        return self

    def __exit__(self, *exc):
        self._texere_obj.language = self._old_language
        return False
