"""
texere

Copyright (c) 2013-2014, Friedrich Paetzke (f.paetzke@gmail.com)
All rights reserved.

"""
import codecs
import os.path


class LazyText:

    def __init__(self, key, values=None):
        self._key = key
        self._values = values

    def __str__(self):
        return Texere().get_text(self._key, self._values)


class Texere:

    _hive_mind = {}

    def __init__(self, dirname=None, language=None, default_language=None):
        self.__dict__ = Texere._hive_mind
        if '_init_was_here_' in self.__dict__:
            return
        self.__dict__['_init_was_here_'] = True
        self._dirname = dirname
        self.language = language
        self._default_language = default_language
        self._dicts = {}

    def get_language(self):
        return self.language

    def get_lazy_text(self, key, values=None):
        return LazyText(key, values)

    def _load_fromfile(self, language):
        filename = self._get_filename()
        f = codecs.open(filename, encoding='utf-8', mode='r')
        content = f.read()
        f.close()
        lang = {}
        for translation in content.split('msgid::\n'):
            id_str = translation.split('msgstr::\n')
            if len(id_str) == 2:
                msg_id, msg_str = id_str
                lang[msg_id.strip()] = msg_str.strip()
        self._dicts[language] = lang

    def _get_text(self, key, values=None):
        lang = self.language
        if lang == self._default_language:
            return key
        if not lang in self._dicts:
            self._load_fromfile(language=lang)

        try:
            s = self._dicts[lang][key]
        except KeyError:
            return None
        if values is not None:
            return s.format(**values)
        return s

    def get_text(self, key, values=None):
        return self._get_text(key, values)

    def _get_filename(self):
        return os.path.join(self._dirname, '{}.lang'.format(self.language))
